==> 0.4.0.tar.gz: lib/src/group.dart <==
part of jaguar_mux.jaguar_mux;

class Group {
  final MuxBuilder _muxBuilder;

  final String pathPrefix;

  final List<RouteWrapper> _wrappers = [];

  List<RouteWrapper> get wrappers => new List.unmodifiable(_wrappers);

  bool _wrapsFinalized = false;

  Group wrap(RouteWrapper interceptor) {
    if (_wrapsFinalized) {
      throw new Exception(
          'All interceptors must be added before adding routes or groups!');
    }
    if (interceptor == null) return this;
    _wrappers.add(interceptor);
    return this;
  }

  Group(this._muxBuilder, {String path: ''}) : pathPrefix = path ?? '';

  Route route(String path, Function handler,
      {Map<String, String> pathRegEx,
      List<String> methods: const <String>['GET', 'PUT', 'POST', 'DELETE']}) {
    Route route = new Route(pathPrefix + (path ?? ''), handler,
        pathRegEx: pathRegEx, methods: methods);
    _muxBuilder.addRoute(route);
    route.wrapAll(_wrappers);
    _wrapsFinalized = true;
    return route;
  }

  Route get(String path, Function handler, {Map<String, String> pathRegEx}) {
    Route route =
        new Route.Get(pathPrefix + (path ?? ''), handler, pathRegEx: pathRegEx);
    _muxBuilder.addRoute(route);
    route.wrapAll(_wrappers);
    _wrapsFinalized = true;
    return route;
  }

  Route post(String path, Function handler, {Map<String, String> pathRegEx}) {
    Route route = new Route.Post(pathPrefix + (path ?? ''), handler,
        pathRegEx: pathRegEx);
    _muxBuilder.addRoute(route);
    route.wrapAll(_wrappers);
    _wrapsFinalized = true;
    return route;
  }

  Route put(String path, Function handler, {Map<String, String> pathRegEx}) {
    Route route =
        new Route.Put(pathPrefix + (path ?? ''), handler, pathRegEx: pathRegEx);
    _muxBuilder.addRoute(route);
    route.wrapAll(_wrappers);
    _wrapsFinalized = true;
    return route;
  }

  Route delete(String path, Function handler, {Map<String, String> pathRegEx}) {
    Route route = new Route.Delete(pathPrefix + (path ?? ''), handler,
        pathRegEx: pathRegEx);
    _muxBuilder.addRoute(route);
    route.wrapAll(_wrappers);
    _wrapsFinalized = true;
    return route;
  }

  Route addRoute(Route route) {
    route._wrapAllAtBeginning(_wrappers);
    _muxBuilder.addRoute(route);
    _wrapsFinalized = true;
    return route;
  }

  Group group({String pathPrefix: ''}) {
    return new Group(_muxBuilder, path: this.pathPrefix + (pathPrefix ?? ''));
  }
}

==> 0.5.1.tar.gz: lib/src/group.dart <==
part of jaguar_mux.jaguar_mux;

class Group {
  final MuxBuilder _muxBuilder;

  final String pathPrefix;

  final List<InterceptorCreator> _wrappers = [];

  List<InterceptorCreator> get wrappers => new List.unmodifiable(_wrappers);

  final exceptionHandlers = <ExceptionHandler>[];

  bool _wrapsFinalized = false;

  Group wrap(InterceptorCreator interceptor) {
    if (_wrapsFinalized) {
      throw new Exception(
          'All interceptors must be added before adding routes or groups!');
    }
    if (interceptor == null) return this;
    _wrappers.add(interceptor);
    return this;
  }

  Group onException(ExceptionHandler exceptionHandler) {
    if (_wrapsFinalized) {
      throw new Exception(
          'All interceptors must be added before adding routes or groups!');
    }
    if (exceptionHandler == null) return this;
    exceptionHandlers.add(exceptionHandler);
    return this;
  }

  Group(this._muxBuilder, {String path: ''}) : pathPrefix = path ?? '';

  Route route(String path, Function handler,
      {Map<String, String> pathRegEx,
      List<String> methods: const <String>['GET', 'PUT', 'POST', 'DELETE']}) {
    Route route = new Route(pathPrefix + (path ?? ''), handler,
        pathRegEx: pathRegEx, methods: methods);
    _muxBuilder.addRoute(route);
    route.wrapAll(_wrappers);
    route.onExceptionAll(exceptionHandlers);
    _wrapsFinalized = true;
    return route;
  }

  Route get(String path, Function handler, {Map<String, String> pathRegEx}) {
    Route route =
        new Route.Get(pathPrefix + (path ?? ''), handler, pathRegEx: pathRegEx);
    _muxBuilder.addRoute(route);
    route.wrapAll(_wrappers);
    route.onExceptionAll(exceptionHandlers);
    _wrapsFinalized = true;
    return route;
  }

  Route post(String path, Function handler, {Map<String, String> pathRegEx}) {
    Route route = new Route.Post(pathPrefix + (path ?? ''), handler,
        pathRegEx: pathRegEx);
    _muxBuilder.addRoute(route);
    route.wrapAll(_wrappers);
    route.onExceptionAll(exceptionHandlers);
    _wrapsFinalized = true;
    return route;
  }

  Route put(String path, Function handler, {Map<String, String> pathRegEx}) {
    Route route =
        new Route.Put(pathPrefix + (path ?? ''), handler, pathRegEx: pathRegEx);
    _muxBuilder.addRoute(route);
    route.wrapAll(_wrappers);
    route.onExceptionAll(exceptionHandlers);
    _wrapsFinalized = true;
    return route;
  }

  Route delete(String path, Function handler, {Map<String, String> pathRegEx}) {
    Route route = new Route.Delete(pathPrefix + (path ?? ''), handler,
        pathRegEx: pathRegEx);
    _muxBuilder.addRoute(route);
    route.wrapAll(_wrappers);
    route.onExceptionAll(exceptionHandlers);
    _wrapsFinalized = true;
    return route;
  }

  Route addRoute(Route route) {
    route._wrapAllAtBeginning(_wrappers);
    route.onExceptionAll(exceptionHandlers);
    _muxBuilder.addRoute(route);
    _wrapsFinalized = true;
    return route;
  }

  Group group({String pathPrefix: ''}) {
    return new Group(_muxBuilder, path: this.pathPrefix + (pathPrefix ?? ''));
  }
}
